//
//  CPDFAnnotationBar.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFAnnotationBar.h"
#import "CPDFAnnotationBarButton.h"

#import <ComPDFKit/ComPDFKit.h>

@interface CPDFAnnotationBar ()

@property (nonatomic, strong) UIScrollView *scrollView;

@property (nonatomic, strong) NSArray *annotationBtns;

@property (nonatomic, assign) NSInteger selectedIndex;

@property (nonatomic, strong) UIView *propertiesBar;

@property (nonatomic, strong) UIButton *propertiesBtn;

@property (nonatomic, strong) UIButton *undoBtn;

@property (nonatomic, strong) UIButton *redoBtn;

@end

@implementation CPDFAnnotationBar

#pragma mark - Initializers

- (instancetype)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
        UIBlurEffect *blur = [UIBlurEffect effectWithStyle:UIBlurEffectStyleExtraLight];
        UIVisualEffectView *effectView = [[UIVisualEffectView alloc] initWithEffect:blur];
        effectView.frame = self.bounds;
        effectView.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
        [self addSubview:effectView];
        
        UIView *line = [[UIView alloc] initWithFrame:CGRectMake(0, 0, frame.size.width, 1)];
        line.backgroundColor = [UIColor colorWithRed:210.0/255.0 green:210.0/255.0 blue:210.0/255.0 alpha:1.0];
        line.autoresizingMask = UIViewAutoresizingFlexibleWidth;
        [self addSubview:line];
        
        self.selectedIndex = -1;

        [self initSubview];
    }
    return self;
}

- (void)layoutSubviews {
    [super layoutSubviews];
    self.scrollView.frame = self.bounds;
}

#pragma mark - Public Methods

- (void)reloadData {
    if (self.selectedIndex >=0 &&
        self.selectedIndex < self.annotationBtns.count) {
        UIButton *selectedButton = [self.annotationBtns objectAtIndex:self.selectedIndex];
        selectedButton.backgroundColor = [UIColor clearColor];
    }
    self.selectedIndex = -1;
}

#pragma mark - Private Methods

- (void)initSubview {
    _propertiesBar = [[UIView alloc] initWithFrame:CGRectMake(self.bounds.size.width - 180, 0, 180, 44)];
    _propertiesBar.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin;
    [self addSubview:self.propertiesBar];
    
    _propertiesBtn = [[UIButton alloc] initWithFrame:CGRectMake(0, 1, 60, 43)];
    [_propertiesBtn setImage:[UIImage imageNamed:@"" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    _propertiesBtn.userInteractionEnabled = NO;
    [_propertiesBtn addTarget:self action:@selector(buttonItemClicked_open:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.propertiesBtn];
    
    _undoBtn = [[UIButton alloc] initWithFrame:CGRectMake(60, 1, 60, 43)];
    [_undoBtn setImage:[UIImage imageNamed:@"" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [_undoBtn addTarget:self action:@selector(buttonItemClicked_undo:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.undoBtn];
    
    _redoBtn = [[UIButton alloc] initWithFrame:CGRectMake(120, 1, 60, 43)];
    [_redoBtn setImage:[UIImage imageNamed:@"" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [_redoBtn addTarget:self action:@selector(buttonItemClicked_redo:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.redoBtn];
    
    _scrollView = [[UIScrollView alloc] initWithFrame:self.bounds];
    _scrollView.showsVerticalScrollIndicator = NO;
    _scrollView.showsHorizontalScrollIndicator = NO;
    [self addSubview:_scrollView];
    
    CGFloat offsetX = 0.0;
    NSArray *images = @[@"CPDFAnnotationBarImageNote",
                        @"CPDFAnnotationBarImageHighLight",
                        @"CPDFAnnotationBarImageUnderline",
                        @"CPDFAnnotationBarImageStrikeout",
                        @"CPDFAnnotationBarImageSquiggly",
                        @"CPDFAnnotationBarImageFreehand",
                        @"CPDFAnnotationBarImageShapeCircle",
                        @"CPDFAnnotationBarImageShapeRectangle",
                        @"CPDFAnnotationBarImageShapeArrow",
                        @"CPDFAnnotationBarImageShapeLine",
                        @"CPDFAnnotationBarImageFreeText",
                        @"CPDFAnnotationBarImageSignature",
                        @"CPDFAnnotationBarImageStamp",
                        @"CPDFAnnotationBarImageImage",
                        @"CPDFAnnotationBarImageLink",
                        @"CPDFAnnotationBarImageSound"];
    
    NSMutableArray *annotationBtns = [NSMutableArray array];
    for (int i = 0; i < images.count; i++) {
        CPDFAnnotationBarButton *button = [CPDFAnnotationBarButton buttonWithType:UIButtonTypeCustom];
        button.frame = CGRectMake(offsetX, 1, 58, 43);
        [button setImage:[UIImage imageNamed:images[i] inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
        button.tag = i;
        button.type = i;
        if (i == 1) {
            button.lineColor = CPDFKitShareConfig.highlightAnnotationColor;
        } else if (i == 2) {
            button.lineColor = CPDFKitShareConfig.underlineAnnotationColor;
        } else if (i == 3) {
            button.lineColor = CPDFKitShareConfig.strikeoutAnnotationColor;
        } else if (i == 4) {
            button.lineColor = CPDFKitShareConfig.squigglyAnnotationColor;
        } else if (i == 5) {
            button.type = 4;
            button.lineColor = CPDFKitShareConfig.freehandAnnotationColor;
        }
        [button addTarget:self action:@selector(buttonItemClicked_Switch:) forControlEvents:UIControlEventTouchUpInside];
        [_scrollView addSubview:button];
        [annotationBtns addObject:button];
        
        if (UIUserInterfaceIdiomPhone == UI_USER_INTERFACE_IDIOM()) {
            offsetX += button.bounds.size.width;
        } else {
            offsetX += button.bounds.size.height;
        }
    }
    self.annotationBtns = annotationBtns;
}

#pragma mark - Action

- (void)buttonItemClicked_Switch:(UIButton *)button {
    if (self.selectedIndex >= 0 && self.selectedIndex < self.annotationBtns.count) {
        UIButton *selectButton = [self.annotationBtns objectAtIndex:self.selectedIndex];
    }
    if (button.tag != self.selectedIndex) {
        button.backgroundColor = [UIColor colorWithRed:178.0/255.0 green:239.0/255.0 blue:253.0/255.0 alpha:1.0];
        self.selectedIndex = button.tag;
        if ([self.delegate respondsToSelector:@selector(clickAnnotationBar:forIndex:forSelected:forAnnotationBarButton:)]) {
            [self.delegate clickAnnotationBar:self forIndex:self.selectedIndex forSelected:YES forAnnotationBarButton:button];
        }
    } else {
        if ([self.delegate respondsToSelector:@selector(clickAnnotationBar:forIndex:forSelected:forAnnotationBarButton:)]) {
            [self.delegate clickAnnotationBar:self forIndex:self.selectedIndex forSelected:YES forAnnotationBarButton:button];
        }
        self.selectedIndex = -1;
    }
}

- (void)buttonItemClicked_open:(UIButton *)button {
    
}

- (void)buttonItemClicked_undo:(UIButton *)button {
    
}

- (void)buttonItemClicked_redo:(UIButton *)button {
    
}

@end
