//
//  CPDFListView.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFListView.h"

#import "CPDFColorUtils.h"

#import "CPDFSlider.h"
#import "CPDFPageIndicatorView.h"

@interface  CPDFListView()

@property (nonatomic, strong) CPDFSlider *pageSliderView;

@property (nonatomic, strong) CPDFPageIndicatorView * pageIndicatorView;

@end

@implementation CPDFListView

#pragma mark - Initializers

- (instancetype)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
        self.backgroundColor = [UIColor lightGrayColor];
        
        [self commomInit];
        
        [self addNotification];
        
    }
    return self;
}

- (id)initWithCoder:(NSCoder *)decoder {
    self = [super initWithCoder:decoder];
    if (self) {
        self.backgroundColor = [UIColor lightGrayColor];

        [self commomInit];

        [self addNotification];
    }
    return self;
}

#pragma mark - Touch

- (void)touchBeganAtPoint:(CGPoint)point forPage:(CPDFPage *)page {
    if (CToolModelAnnotation == self.toolModel) {
        
    } else if (CToolModelForm == self.toolModel) {
        
    } else if (CToolModelEdit == self.toolModel) {
        
    } else {
    }
}

- (void)touchMovedAtPoint:(CGPoint)point forPage:(CPDFPage *)page {
    if (CToolModelAnnotation == self.toolModel) {
        
    } else if (CToolModelForm == self.toolModel) {
        
    } else if (CToolModelEdit == self.toolModel) {
        
    } else {
    }
}

- (void)touchEndedAtPoint:(CGPoint)point forPage:(CPDFPage *)page {
    if (CToolModelAnnotation == self.toolModel) {
        
    } else if (CToolModelForm == self.toolModel) {
        
    } else if (CToolModelEdit == self.toolModel) {
        
    } else {
    }
}

- (void)touchCancelledAtPoint:(CGPoint)point forPage:(CPDFPage *)page {
    if (CToolModelAnnotation == self.toolModel) {
        
    } else if (CToolModelForm == self.toolModel) {
        
    } else if (CToolModelEdit == self.toolModel) {
        
    } else {
    }
}

- (NSArray<UIMenuItem *> *)menuItemsAtPoint:(CGPoint)point forPage:(CPDFPage *)page {
    if([self.performDelegate respondsToSelector:@selector(PDFListView:customizeMenuForPage:forPagePoint:)])
        return [self.performDelegate PDFListView:self customizeMenuForPage:page forPagePoint:point];

    return [super menuItemsAtPoint:point forPage:page];
}

#pragma mark - Private method

- (void)commomInit {
    _pageSliderView = [[CPDFSlider alloc] initWithPDFView:self];
    _pageSliderView.frame = CGRectMake(self.bounds.size.width-22, 0, 22, self.bounds.size.height);
    _pageSliderView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleLeftMargin;
    [self addSubview:self.pageSliderView];
    
    _pageIndicatorView = [[CPDFPageIndicatorView alloc] init];
    
    __weak typeof(self) weakSelf = self;
    _pageIndicatorView.touchCallBack = ^{
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:nil message:NSLocalizedString(@"Go to page", nil) preferredStyle:UIAlertControllerStyleAlert];
        
        [alertController addAction:[UIAlertAction actionWithTitle:NSLocalizedString(@"Cancel", nil) style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
            
        }]];
        
        [alertController addAction:[UIAlertAction actionWithTitle:NSLocalizedString(@"Done", nil) style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
            
            UITextField *pageTextField = alertController.textFields.firstObject;
            NSInteger pageIndex = [pageTextField.text integerValue] - 1;
            
            if (pageIndex > weakSelf.document.pageCount){
                pageIndex = weakSelf.document.pageCount;
            } else if(pageIndex<0){
                pageIndex = 0;
            } else  if(pageTextField.text.length == 0){
                pageIndex = (int)weakSelf.currentPageIndex;
            }
            
            [weakSelf goToPageIndex:pageIndex animated:YES];
        }]];
        
        [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
            
            textField.placeholder = NSLocalizedString(@"Enter a page number", nil);
            textField.keyboardType = UIKeyboardTypeNumberPad;
            
        }];
        
        UIViewController *tRootViewControl = self.window.rootViewController;
        if ([tRootViewControl presentedViewController]) {
            tRootViewControl = [tRootViewControl presentedViewController];
        }
        
        [tRootViewControl presentViewController:alertController animated:true completion:nil];
    };
}

- (void)addNotification {
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(documentChangedNotification:) name:CPDFViewDocumentChangedNotification object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(pageChangedNotification:) name:CPDFViewPageChangedNotification object:nil];
}

- (void)showPageNumIndicator {
    __weak typeof(self) weakSelf = self;
    if(![self.pageIndicatorView superview])
        [self.pageIndicatorView showInView:weakSelf position:CPDFPageIndicatorViewPositionLeftBottom];

    [self.pageIndicatorView updatePageCount:weakSelf.document.pageCount currentPageIndex:self.currentPageIndex + 1];
}

#pragma mark - NotificationCenter

- (void)documentChangedNotification:(NSNotification *)notification {
    CPDFView *pdfview = notification.object;
    if (pdfview.document == self.document) {
        [self showPageNumIndicator];
        [self.pageSliderView reloadData];
    }
}

- (void)pageChangedNotification:(NSNotification *)notification {
    CPDFView *pdfview = notification.object;
    if (pdfview.document == self.document) {
        [self showPageNumIndicator];
        [self.pageSliderView reloadData];
    }
}

@end
