//
//  PDFThumbnailViewCell.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFThumbnailViewCell.h"

@implementation CPDFThumbnailViewCell

- (instancetype)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
        _imageView = [[UIImageView alloc] init];
        _imageView.layer.borderWidth = 1.0;
        _imageView.layer.borderColor = [UIColor colorWithRed:214.0/255.0 green:214.0/255.0 blue:214.0/255.0 alpha:1.0].CGColor;
        [self.contentView addSubview:_imageView];
        
        _textLabel = [[UILabel alloc] initWithFrame:CGRectMake(0, frame.size.height - 12, frame.size.width, 12)];
        _textLabel.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleTopMargin;
        _textLabel.textAlignment = NSTextAlignmentCenter;
        _textLabel.font = [UIFont systemFontOfSize:10];
        _textLabel.textColor = [UIColor blackColor];
        [self.contentView addSubview:_textLabel];
    }
    return self;
}

- (void)drawRect:(CGRect)rect {
    _imageView.frame = CGRectMake((self.frame.size.width - self.imageSize.width)/2, (self.imageSize.height - 12 - self.imageSize.height) / 2, self.imageSize.width, self.imageSize.height);
    _textLabel.frame = CGRectMake(0, self.imageSize.height + (self.imageSize.height - 12 - self.imageSize.height) / 2, self.frame.size.width, 12);
}

- (void)setPageRef:(CGPDFPageRef)pageRef {
    CGRect boxRect = CGRectZero;
    if (pageRef) {
        boxRect = CGPDFPageGetBoxRect(pageRef, kCGPDFCropBox);
        CGRect displayBounds = CGRectMake(0, 0, self.bounds.size.width, self.bounds.size.height - 12);
        CGAffineTransform transform = CGPDFPageGetDrawingTransform(pageRef,
                                                                   kCGPDFCropBox,
                                                                   displayBounds,
                                                                   0,
                                                                   true);
        boxRect = CGRectApplyAffineTransform(boxRect, transform);
    }
}

- (void)setSelected:(BOOL)selected {
    [super setSelected:selected];
    if (selected) {
        self.textLabel.textColor = [UIColor colorWithRed:0.0 green:124.0/255.0 blue:1.0 alpha:1.0];
    } else {
        self.textLabel.textColor = [UIColor blackColor];
    }
}

@end
